# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: events.proto
# Protobuf Python Version: 6.30.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    1,
    '',
    'events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65vents.proto\x12\rrtech.liveapi\x1a\x19google/protobuf/any.proto\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"\xbe\x02\n\x06Player\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06teamId\x18\x02 \x01(\r\x12#\n\x03pos\x18\x03 \x01(\x0b\x32\x16.rtech.liveapi.Vector3\x12&\n\x06\x61ngles\x18\x04 \x01(\x0b\x32\x16.rtech.liveapi.Vector3\x12\x15\n\rcurrentHealth\x18\x05 \x01(\r\x12\x11\n\tmaxHealth\x18\x06 \x01(\r\x12\x14\n\x0cshieldHealth\x18\x07 \x01(\r\x12\x17\n\x0fshieldMaxHealth\x18\x08 \x01(\r\x12\x13\n\x0bnucleusHash\x18\t \x01(\t\x12\x14\n\x0chardwareName\x18\n \x01(\t\x12\x10\n\x08teamName\x18\x0b \x01(\t\x12\x12\n\nsquadIndex\x18\x0c \x01(\r\x12\x11\n\tcharacter\x18\r \x01(\t\x12\x0c\n\x04skin\x18\x0e \x01(\t\"b\n\x17\x43ustomMatch_LobbyPlayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06teamId\x18\x02 \x01(\r\x12\x13\n\x0bnucleusHash\x18\x03 \x01(\t\x12\x14\n\x0chardwareName\x18\x04 \x01(\t\"@\n\x10\x43ustomMatch_Team\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nspawnPoint\x18\x03 \x01(\x05\"D\n\x11LegendMatchStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x03 \x01(\x08\"?\n\nDatacenter\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"V\n\x07Version\x12\x11\n\tmajor_num\x18\x01 \x01(\r\x12\x11\n\tminor_num\x18\x02 \x01(\r\x12\x13\n\x0b\x62uild_stamp\x18\x03 \x01(\r\x12\x10\n\x08revision\x18\x04 \x01(\t\"B\n\rInventoryItem\x12\x10\n\x08quantity\x18\x01 \x01(\x05\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\x11\n\textraData\x18\x03 \x01(\t\"v\n\x14LoadoutConfiguration\x12-\n\x07weapons\x18\x01 \x03(\x0b\x32\x1c.rtech.liveapi.InventoryItem\x12/\n\tequipment\x18\x02 \x03(\x0b\x32\x1c.rtech.liveapi.InventoryItem\"g\n\x1cPauseStateChangeNotification\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x11\n\tisPausing\x18\x02 \x01(\x08\x12\x10\n\x08timeLeft\x18\x03 \x01(\x04\x12\x0f\n\x07message\x18\x04 \x01(\t\"\x8c\x01\n\x04Init\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x13\n\x0bgameVersion\x18\x03 \x01(\t\x12*\n\napiVersion\x18\x04 \x01(\x0b\x32\x16.rtech.liveapi.Version\x12\x10\n\x08platform\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\x98\x01\n\x18\x43ustomMatch_LobbyPlayers\x12\x13\n\x0bplayerToken\x18\x01 \x01(\t\x12\x37\n\x07players\x18\x02 \x03(\x0b\x32&.rtech.liveapi.CustomMatch_LobbyPlayer\x12.\n\x05teams\x18\x03 \x03(\x0b\x32\x1f.rtech.liveapi.CustomMatch_Team\"P\n\x1b\x43ustomMatch_LegendBanStatus\x12\x31\n\x07legends\x18\x03 \x03(\x0b\x32 .rtech.liveapi.LegendMatchStatus\"\xb2\x01\n\x10ObserverSwitched\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08observer\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06target\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12)\n\ntargetTeam\x18\x05 \x03(\x0b\x32\x15.rtech.liveapi.Player\"S\n\x12ObserverAnnotation\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x18\n\x10\x61nnotationSerial\x18\x03 \x01(\x05\"\x95\x02\n\nMatchSetup\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0b\n\x03map\x18\x03 \x01(\t\x12\x14\n\x0cplaylistName\x18\x04 \x01(\t\x12\x14\n\x0cplaylistDesc\x18\x05 \x01(\t\x12-\n\ndatacenter\x18\x06 \x01(\x0b\x32\x19.rtech.liveapi.Datacenter\x12\x13\n\x0b\x61imAssistOn\x18\x07 \x01(\x08\x12\x15\n\ranonymousMode\x18\x08 \x01(\x08\x12\x10\n\x08serverId\x18\t \x01(\t\x12<\n\x0fstartingLoadout\x18\n \x01(\x0b\x32#.rtech.liveapi.LoadoutConfiguration\"F\n\x10GameStateChanged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\"_\n\x11\x43haracterSelected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\"k\n\rMatchStateEnd\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12&\n\x07winners\x18\x04 \x03(\x0b\x32\x15.rtech.liveapi.Player\"\xb0\x01\n\x10RingStartClosing\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\r\x12&\n\x06\x63\x65nter\x18\x04 \x01(\x0b\x32\x16.rtech.liveapi.Vector3\x12\x15\n\rcurrentRadius\x18\x05 \x01(\x02\x12\x11\n\tendRadius\x18\x06 \x01(\x02\x12\x16\n\x0eshrinkDuration\x18\x07 \x01(\x02\"\xa0\x01\n\x13RingFinishedClosing\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\r\x12&\n\x06\x63\x65nter\x18\x04 \x01(\x0b\x32\x16.rtech.liveapi.Vector3\x12\x15\n\rcurrentRadius\x18\x05 \x01(\x02\x12\x16\n\x0eshrinkDuration\x18\x07 \x01(\x02\"]\n\x0fPlayerConnected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\"\x87\x01\n\x12PlayerDisconnected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x14\n\x0c\x63\x61nReconnect\x18\x04 \x01(\x08\x12\x0f\n\x07isAlive\x18\x05 \x01(\x08\"\x83\x01\n\x11PlayerStatChanged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x10\n\x08statName\x18\x04 \x01(\t\x12\x10\n\x08newValue\x18\x05 \x01(\r\"u\n\x18PlayerUpgradeTierChanged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\r\n\x05level\x18\x04 \x01(\x05\"\xad\x01\n\rPlayerDamaged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08\x61ttacker\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0e\n\x06weapon\x18\x05 \x01(\t\x12\x17\n\x0f\x64\x61mageInflicted\x18\x06 \x01(\r\"\xbd\x01\n\x0cPlayerKilled\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08\x61ttacker\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12(\n\tawardedTo\x18\x05 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0e\n\x06weapon\x18\x06 \x01(\t\"\x93\x01\n\x0cPlayerDowned\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08\x61ttacker\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0e\n\x06weapon\x18\x05 \x01(\t\"\x94\x01\n\x0cPlayerAssist\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12(\n\tassistant\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0e\n\x06weapon\x18\x05 \x01(\t\"^\n\x0fSquadEliminated\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12&\n\x07players\x18\x03 \x03(\x0b\x32\x15.rtech.liveapi.Player\"y\n\x15PlayerUltimateCharged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x14\n\x0clinkedEntity\x18\x04 \x01(\t\"\xa7\x01\n\x17GibraltarShieldAbsorbed\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08\x61ttacker\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x17\n\x0f\x64\x61mageInflicted\x18\x06 \x01(\r\"\xab\x01\n\x1bRevenantForgedShadowDamaged\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\'\n\x08\x61ttacker\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12%\n\x06victim\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x17\n\x0f\x64\x61mageInflicted\x18\x06 \x01(\r\"\xa5\x01\n\x11PlayerRespawnTeam\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x11\n\trespawned\x18\x04 \x01(\t\x12\x31\n\x12respawnedTeammates\x18\x05 \x03(\x0b\x32\x15.rtech.liveapi.Player\"\x82\x01\n\x0cPlayerRevive\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12&\n\x07revived\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\"\x80\x01\n\x12\x41renasItemSelected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x05\"\x82\x01\n\x14\x41renasItemDeselected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x05\"}\n\x0fInventoryPickUp\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x05\"\x8e\x01\n\rInventoryDrop\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x05\x12\x11\n\textraData\x18\x06 \x03(\t\"z\n\x0cInventoryUse\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\x05\"\x87\x01\n\x0f\x42\x61nnerCollected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12(\n\tcollected\x18\x04 \x01(\x0b\x32\x15.rtech.liveapi.Player\"u\n\x11PlayerAbilityUsed\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x14\n\x0clinkedEntity\x18\x04 \x01(\t\"\x9c\x01\n\x15LegendUpgradeSelected\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x13\n\x0bupgradeName\x18\x04 \x01(\t\x12\x13\n\x0bupgradeDesc\x18\x05 \x01(\t\x12\r\n\x05level\x18\x06 \x01(\x05\"o\n\x0bZiplineUsed\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x14\n\x0clinkedEntity\x18\x04 \x01(\t\"q\n\rGrenadeThrown\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x14\n\x0clinkedEntity\x18\x04 \x01(\t\"m\n\x11\x42lackMarketAction\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x0c\n\x04item\x18\x04 \x01(\t\"Z\n\x0cWraithPortal\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\"Z\n\x0cWarpGateUsed\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\"\xa8\x01\n\x08\x41mmoUsed\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x10\n\x08\x61mmoType\x18\x04 \x01(\t\x12\x12\n\namountUsed\x18\x05 \x01(\r\x12\x14\n\x0coldAmmoCount\x18\x06 \x01(\r\x12\x14\n\x0cnewAmmoCount\x18\x07 \x01(\r\"\x82\x01\n\x0eWeaponSwitched\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12%\n\x06player\x18\x03 \x01(\x0b\x32\x15.rtech.liveapi.Player\x12\x11\n\toldWeapon\x18\x04 \x01(\t\x12\x11\n\tnewWeapon\x18\x05 \x01(\t\"o\n\x0c\x43hangeCamera\x12.\n\x03poi\x18\x01 \x01(\x0e\x32\x1f.rtech.liveapi.PlayerOfInterestH\x00\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x15\n\x0bnucleusHash\x18\x03 \x01(\tH\x00\x42\x08\n\x06target\"\x1f\n\x0bPauseToggle\x12\x10\n\x08preTimer\x18\x01 \x01(\x02\"\x19\n\x17\x43ustomMatch_CreateLobby\"*\n\x15\x43ustomMatch_JoinLobby\x12\x11\n\troleToken\x18\x01 \x01(\t\"\x18\n\x16\x43ustomMatch_LeaveLobby\"\'\n\x14\x43ustomMatch_SetReady\x12\x0f\n\x07isReady\x18\x01 \x01(\x08\"\x1d\n\x1b\x43ustomMatch_GetLobbyPlayers\"-\n\x1a\x43ustomMatch_SetMatchmaking\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\\\n\x13\x43ustomMatch_SetTeam\x12\x0e\n\x06teamId\x18\x01 \x01(\x05\x12\x1a\n\x12targetHardwareName\x18\x02 \x01(\t\x12\x19\n\x11targetNucleusHash\x18\x03 \x01(\t\"O\n\x16\x43ustomMatch_KickPlayer\x12\x1a\n\x12targetHardwareName\x18\x01 \x01(\t\x12\x19\n\x11targetNucleusHash\x18\x02 \x01(\t\"\x8f\x01\n\x17\x43ustomMatch_SetSettings\x12\x14\n\x0cplaylistName\x18\x01 \x01(\t\x12\x11\n\tadminChat\x18\x02 \x01(\x08\x12\x12\n\nteamRename\x18\x03 \x01(\x08\x12\x12\n\nselfAssign\x18\x04 \x01(\x08\x12\x11\n\taimAssist\x18\x05 \x01(\x08\x12\x10\n\x08\x61nonMode\x18\x06 \x01(\x08\"\x19\n\x17\x43ustomMatch_GetSettings\";\n\x17\x43ustomMatch_SetTeamName\x12\x0e\n\x06teamId\x18\x01 \x01(\x05\x12\x10\n\x08teamName\x18\x02 \x01(\t\"?\n\x19\x43ustomMatch_SetSpawnPoint\x12\x0e\n\x06teamId\x18\x01 \x01(\x05\x12\x12\n\nspawnPoint\x18\x02 \x01(\x05\"U\n\x1f\x43ustomMatch_SetEndRingExclusion\x12\x32\n\x10sectionToExclude\x18\x01 \x01(\x0e\x32\x18.rtech.liveapi.MapRegion\" \n\x1e\x43ustomMatch_GetLegendBanStatus\".\n\x18\x43ustomMatch_SetLegendBan\x12\x12\n\nlegendRefs\x18\x01 \x03(\t\"$\n\x14\x43ustomMatch_SendChat\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xe6\n\n\x07Request\x12\x0f\n\x07withAck\x18\x01 \x01(\x08\x12\x14\n\x0cpreSharedKey\x18\x02 \x01(\t\x12\x30\n\tchangeCam\x18\x04 \x01(\x0b\x32\x1b.rtech.liveapi.ChangeCameraH\x00\x12\x31\n\x0bpauseToggle\x18\x05 \x01(\x0b\x32\x1a.rtech.liveapi.PauseToggleH\x00\x12I\n\x17\x63ustomMatch_CreateLobby\x18\n \x01(\x0b\x32&.rtech.liveapi.CustomMatch_CreateLobbyH\x00\x12\x45\n\x15\x63ustomMatch_JoinLobby\x18\x0b \x01(\x0b\x32$.rtech.liveapi.CustomMatch_JoinLobbyH\x00\x12G\n\x16\x63ustomMatch_LeaveLobby\x18\x0c \x01(\x0b\x32%.rtech.liveapi.CustomMatch_LeaveLobbyH\x00\x12\x43\n\x14\x63ustomMatch_SetReady\x18\r \x01(\x0b\x32#.rtech.liveapi.CustomMatch_SetReadyH\x00\x12O\n\x1a\x63ustomMatch_SetMatchmaking\x18\x0e \x01(\x0b\x32).rtech.liveapi.CustomMatch_SetMatchmakingH\x00\x12\x41\n\x13\x63ustomMatch_SetTeam\x18\x0f \x01(\x0b\x32\".rtech.liveapi.CustomMatch_SetTeamH\x00\x12G\n\x16\x63ustomMatch_KickPlayer\x18\x10 \x01(\x0b\x32%.rtech.liveapi.CustomMatch_KickPlayerH\x00\x12I\n\x17\x63ustomMatch_SetSettings\x18\x11 \x01(\x0b\x32&.rtech.liveapi.CustomMatch_SetSettingsH\x00\x12\x43\n\x14\x63ustomMatch_SendChat\x18\x12 \x01(\x0b\x32#.rtech.liveapi.CustomMatch_SendChatH\x00\x12Q\n\x1b\x63ustomMatch_GetLobbyPlayers\x18\x13 \x01(\x0b\x32*.rtech.liveapi.CustomMatch_GetLobbyPlayersH\x00\x12I\n\x17\x63ustomMatch_SetTeamName\x18\x14 \x01(\x0b\x32&.rtech.liveapi.CustomMatch_SetTeamNameH\x00\x12I\n\x17\x63ustomMatch_GetSettings\x18\x15 \x01(\x0b\x32&.rtech.liveapi.CustomMatch_GetSettingsH\x00\x12M\n\x19\x63ustomMatch_SetSpawnPoint\x18\x16 \x01(\x0b\x32(.rtech.liveapi.CustomMatch_SetSpawnPointH\x00\x12Y\n\x1f\x63ustomMatch_SetEndRingExclusion\x18\x17 \x01(\x0b\x32..rtech.liveapi.CustomMatch_SetEndRingExclusionH\x00\x12W\n\x1e\x63ustomMatch_GetLegendBanStatus\x18\x18 \x01(\x0b\x32-.rtech.liveapi.CustomMatch_GetLegendBanStatusH\x00\x12K\n\x18\x63ustomMatch_SetLegendBan\x18\x19 \x01(\x0b\x32\'.rtech.liveapi.CustomMatch_SetLegendBanH\x00\x42\t\n\x07\x61\x63tions\"\x1f\n\rRequestStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\"A\n\x08Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06result\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"M\n\x0cLiveAPIEvent\x12\x12\n\nevent_size\x18\x01 \x01(\x07\x12)\n\x0bgameMessage\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any*\x88\x01\n\x10PlayerOfInterest\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04NEXT\x10\x01\x12\x0c\n\x08PREVIOUS\x10\x02\x12\x0f\n\x0bKILL_LEADER\x10\x03\x12\x11\n\rCLOSEST_ENEMY\x10\x04\x12\x12\n\x0e\x43LOSEST_PLAYER\x10\x05\x12\x13\n\x0fLATEST_ATTACKER\x10\x06*j\n\tMapRegion\x12\x0c\n\x08TOP_LEFT\x10\x00\x12\r\n\tTOP_RIGHT\x10\x01\x12\x0f\n\x0b\x42OTTOM_LEFT\x10\x02\x12\x10\n\x0c\x42OTTOM_RIGHT\x10\x03\x12\n\n\x06\x43\x45NTER\x10\x04\x12\x11\n\rREGIONS_COUNT\x10\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PLAYEROFINTEREST']._serialized_start=9181
  _globals['_PLAYEROFINTEREST']._serialized_end=9317
  _globals['_MAPREGION']._serialized_start=9319
  _globals['_MAPREGION']._serialized_end=9425
  _globals['_VECTOR3']._serialized_start=58
  _globals['_VECTOR3']._serialized_end=100
  _globals['_PLAYER']._serialized_start=103
  _globals['_PLAYER']._serialized_end=421
  _globals['_CUSTOMMATCH_LOBBYPLAYER']._serialized_start=423
  _globals['_CUSTOMMATCH_LOBBYPLAYER']._serialized_end=521
  _globals['_CUSTOMMATCH_TEAM']._serialized_start=523
  _globals['_CUSTOMMATCH_TEAM']._serialized_end=587
  _globals['_LEGENDMATCHSTATUS']._serialized_start=589
  _globals['_LEGENDMATCHSTATUS']._serialized_end=657
  _globals['_DATACENTER']._serialized_start=659
  _globals['_DATACENTER']._serialized_end=722
  _globals['_VERSION']._serialized_start=724
  _globals['_VERSION']._serialized_end=810
  _globals['_INVENTORYITEM']._serialized_start=812
  _globals['_INVENTORYITEM']._serialized_end=878
  _globals['_LOADOUTCONFIGURATION']._serialized_start=880
  _globals['_LOADOUTCONFIGURATION']._serialized_end=998
  _globals['_PAUSESTATECHANGENOTIFICATION']._serialized_start=1000
  _globals['_PAUSESTATECHANGENOTIFICATION']._serialized_end=1103
  _globals['_INIT']._serialized_start=1106
  _globals['_INIT']._serialized_end=1246
  _globals['_CUSTOMMATCH_LOBBYPLAYERS']._serialized_start=1249
  _globals['_CUSTOMMATCH_LOBBYPLAYERS']._serialized_end=1401
  _globals['_CUSTOMMATCH_LEGENDBANSTATUS']._serialized_start=1403
  _globals['_CUSTOMMATCH_LEGENDBANSTATUS']._serialized_end=1483
  _globals['_OBSERVERSWITCHED']._serialized_start=1486
  _globals['_OBSERVERSWITCHED']._serialized_end=1664
  _globals['_OBSERVERANNOTATION']._serialized_start=1666
  _globals['_OBSERVERANNOTATION']._serialized_end=1749
  _globals['_MATCHSETUP']._serialized_start=1752
  _globals['_MATCHSETUP']._serialized_end=2029
  _globals['_GAMESTATECHANGED']._serialized_start=2031
  _globals['_GAMESTATECHANGED']._serialized_end=2101
  _globals['_CHARACTERSELECTED']._serialized_start=2103
  _globals['_CHARACTERSELECTED']._serialized_end=2198
  _globals['_MATCHSTATEEND']._serialized_start=2200
  _globals['_MATCHSTATEEND']._serialized_end=2307
  _globals['_RINGSTARTCLOSING']._serialized_start=2310
  _globals['_RINGSTARTCLOSING']._serialized_end=2486
  _globals['_RINGFINISHEDCLOSING']._serialized_start=2489
  _globals['_RINGFINISHEDCLOSING']._serialized_end=2649
  _globals['_PLAYERCONNECTED']._serialized_start=2651
  _globals['_PLAYERCONNECTED']._serialized_end=2744
  _globals['_PLAYERDISCONNECTED']._serialized_start=2747
  _globals['_PLAYERDISCONNECTED']._serialized_end=2882
  _globals['_PLAYERSTATCHANGED']._serialized_start=2885
  _globals['_PLAYERSTATCHANGED']._serialized_end=3016
  _globals['_PLAYERUPGRADETIERCHANGED']._serialized_start=3018
  _globals['_PLAYERUPGRADETIERCHANGED']._serialized_end=3135
  _globals['_PLAYERDAMAGED']._serialized_start=3138
  _globals['_PLAYERDAMAGED']._serialized_end=3311
  _globals['_PLAYERKILLED']._serialized_start=3314
  _globals['_PLAYERKILLED']._serialized_end=3503
  _globals['_PLAYERDOWNED']._serialized_start=3506
  _globals['_PLAYERDOWNED']._serialized_end=3653
  _globals['_PLAYERASSIST']._serialized_start=3656
  _globals['_PLAYERASSIST']._serialized_end=3804
  _globals['_SQUADELIMINATED']._serialized_start=3806
  _globals['_SQUADELIMINATED']._serialized_end=3900
  _globals['_PLAYERULTIMATECHARGED']._serialized_start=3902
  _globals['_PLAYERULTIMATECHARGED']._serialized_end=4023
  _globals['_GIBRALTARSHIELDABSORBED']._serialized_start=4026
  _globals['_GIBRALTARSHIELDABSORBED']._serialized_end=4193
  _globals['_REVENANTFORGEDSHADOWDAMAGED']._serialized_start=4196
  _globals['_REVENANTFORGEDSHADOWDAMAGED']._serialized_end=4367
  _globals['_PLAYERRESPAWNTEAM']._serialized_start=4370
  _globals['_PLAYERRESPAWNTEAM']._serialized_end=4535
  _globals['_PLAYERREVIVE']._serialized_start=4538
  _globals['_PLAYERREVIVE']._serialized_end=4668
  _globals['_ARENASITEMSELECTED']._serialized_start=4671
  _globals['_ARENASITEMSELECTED']._serialized_end=4799
  _globals['_ARENASITEMDESELECTED']._serialized_start=4802
  _globals['_ARENASITEMDESELECTED']._serialized_end=4932
  _globals['_INVENTORYPICKUP']._serialized_start=4934
  _globals['_INVENTORYPICKUP']._serialized_end=5059
  _globals['_INVENTORYDROP']._serialized_start=5062
  _globals['_INVENTORYDROP']._serialized_end=5204
  _globals['_INVENTORYUSE']._serialized_start=5206
  _globals['_INVENTORYUSE']._serialized_end=5328
  _globals['_BANNERCOLLECTED']._serialized_start=5331
  _globals['_BANNERCOLLECTED']._serialized_end=5466
  _globals['_PLAYERABILITYUSED']._serialized_start=5468
  _globals['_PLAYERABILITYUSED']._serialized_end=5585
  _globals['_LEGENDUPGRADESELECTED']._serialized_start=5588
  _globals['_LEGENDUPGRADESELECTED']._serialized_end=5744
  _globals['_ZIPLINEUSED']._serialized_start=5746
  _globals['_ZIPLINEUSED']._serialized_end=5857
  _globals['_GRENADETHROWN']._serialized_start=5859
  _globals['_GRENADETHROWN']._serialized_end=5972
  _globals['_BLACKMARKETACTION']._serialized_start=5974
  _globals['_BLACKMARKETACTION']._serialized_end=6083
  _globals['_WRAITHPORTAL']._serialized_start=6085
  _globals['_WRAITHPORTAL']._serialized_end=6175
  _globals['_WARPGATEUSED']._serialized_start=6177
  _globals['_WARPGATEUSED']._serialized_end=6267
  _globals['_AMMOUSED']._serialized_start=6270
  _globals['_AMMOUSED']._serialized_end=6438
  _globals['_WEAPONSWITCHED']._serialized_start=6441
  _globals['_WEAPONSWITCHED']._serialized_end=6571
  _globals['_CHANGECAMERA']._serialized_start=6573
  _globals['_CHANGECAMERA']._serialized_end=6684
  _globals['_PAUSETOGGLE']._serialized_start=6686
  _globals['_PAUSETOGGLE']._serialized_end=6717
  _globals['_CUSTOMMATCH_CREATELOBBY']._serialized_start=6719
  _globals['_CUSTOMMATCH_CREATELOBBY']._serialized_end=6744
  _globals['_CUSTOMMATCH_JOINLOBBY']._serialized_start=6746
  _globals['_CUSTOMMATCH_JOINLOBBY']._serialized_end=6788
  _globals['_CUSTOMMATCH_LEAVELOBBY']._serialized_start=6790
  _globals['_CUSTOMMATCH_LEAVELOBBY']._serialized_end=6814
  _globals['_CUSTOMMATCH_SETREADY']._serialized_start=6816
  _globals['_CUSTOMMATCH_SETREADY']._serialized_end=6855
  _globals['_CUSTOMMATCH_GETLOBBYPLAYERS']._serialized_start=6857
  _globals['_CUSTOMMATCH_GETLOBBYPLAYERS']._serialized_end=6886
  _globals['_CUSTOMMATCH_SETMATCHMAKING']._serialized_start=6888
  _globals['_CUSTOMMATCH_SETMATCHMAKING']._serialized_end=6933
  _globals['_CUSTOMMATCH_SETTEAM']._serialized_start=6935
  _globals['_CUSTOMMATCH_SETTEAM']._serialized_end=7027
  _globals['_CUSTOMMATCH_KICKPLAYER']._serialized_start=7029
  _globals['_CUSTOMMATCH_KICKPLAYER']._serialized_end=7108
  _globals['_CUSTOMMATCH_SETSETTINGS']._serialized_start=7111
  _globals['_CUSTOMMATCH_SETSETTINGS']._serialized_end=7254
  _globals['_CUSTOMMATCH_GETSETTINGS']._serialized_start=7256
  _globals['_CUSTOMMATCH_GETSETTINGS']._serialized_end=7281
  _globals['_CUSTOMMATCH_SETTEAMNAME']._serialized_start=7283
  _globals['_CUSTOMMATCH_SETTEAMNAME']._serialized_end=7342
  _globals['_CUSTOMMATCH_SETSPAWNPOINT']._serialized_start=7344
  _globals['_CUSTOMMATCH_SETSPAWNPOINT']._serialized_end=7407
  _globals['_CUSTOMMATCH_SETENDRINGEXCLUSION']._serialized_start=7409
  _globals['_CUSTOMMATCH_SETENDRINGEXCLUSION']._serialized_end=7494
  _globals['_CUSTOMMATCH_GETLEGENDBANSTATUS']._serialized_start=7496
  _globals['_CUSTOMMATCH_GETLEGENDBANSTATUS']._serialized_end=7528
  _globals['_CUSTOMMATCH_SETLEGENDBAN']._serialized_start=7530
  _globals['_CUSTOMMATCH_SETLEGENDBAN']._serialized_end=7576
  _globals['_CUSTOMMATCH_SENDCHAT']._serialized_start=7578
  _globals['_CUSTOMMATCH_SENDCHAT']._serialized_end=7614
  _globals['_REQUEST']._serialized_start=7617
  _globals['_REQUEST']._serialized_end=8999
  _globals['_REQUESTSTATUS']._serialized_start=9001
  _globals['_REQUESTSTATUS']._serialized_end=9032
  _globals['_RESPONSE']._serialized_start=9034
  _globals['_RESPONSE']._serialized_end=9099
  _globals['_LIVEAPIEVENT']._serialized_start=9101
  _globals['_LIVEAPIEVENT']._serialized_end=9178
# @@protoc_insertion_point(module_scope)
